@@ -3,7 +3,7 @@ import os
 import requests
 import sys
 from datetime import datetime
-from typing import Dict
+from typing import Dict, List
 
 # # TODO should not ignore this warning. Remove when the pkm certificate will
 # # be corrected
@@ -105,22 +105,22 @@ class PKMClient(object):
         return datetime.now().strftime("%Y%m%d_%H%M%S")
 
     def update_invocation(self, project_id: str, invocation_id: str, status: int,
-                          resultsToAdd: Dict[str, str]):
+                          resultsToAdd: List[Dict[str, str]]):
         """
         """
         print(f"PKMClient.update_invocation {project_id}, {invocation_id}, {status}"
               f", {json.dumps(resultsToAdd)}", file=sys.stderr)
+
         invocationUpdate = dict()
         invocationUpdate["invocationID"] = invocation_id
 
         if status == 0:
             invocationUpdate["invocationStatus"] = "COMPLETED"
+            invocationUpdate["invocationResults"] = resultsToAdd
         else:
             invocationUpdate["invocationStatus"] = "FAILED"
-            invocationUpdate["invocationResults"] = resultsToAdd.update(
-                path="FAILED", type="message")
-
-        invocationUpdate["invocationResults"] = resultsToAdd
+            invocationUpdate["invocationResults"] = resultsToAdd.append(
+                {"path": "FAILED", "type": "message"})
 
         invocationUpdate["timestampCompleted"] = self.now()
 
@@ -128,6 +128,8 @@ class PKMClient(object):
         getSt, getTx = self.call(
             method='GET',
             path=path)
+        print(f"update_invocation: Got status {getSt} from PKM and data {getTx}",
+              file=sys.stderr)
 
         if getSt >= 300:
             print(f"Got http error {getSt} retrieving invocation data from PKM with "
